@@ -1,23 +1,42 @@
 "A zero-length string is invalid                                         ",&
 "Argument beta has incorect length                                       ",&
+"Argument beta has incorrect shape                                       ",&
+"Argument beta_series has incorrect shape                                ",&
 "Argument criterion cannot be negative                                   ",&
+"Argument imp_list has incorrect shape                                   ",&
 "Argument impute_every cannot be negative                                ",&
 "Argument impute_every cannot exceed max_iter                            ",&
 "Argument iwkp has incorect length                                       ",&
+"Argument loglik has incorrect size                                      ",&
+"Argument logpost has incorrect size                                     ",&
 "Argument max_iter cannot be negative                                    ",&
 "Argument max_iter must be positive                                      ",&
+"Argument mis has incorrect shape                                        ",&
+"Argument mis_int has incorrect size                                     ",&
 "Argument multicycle must be positive                                    ",&
+"Argument n_in_patt has incorrect size                                   ",&
+"Argument nobs has incorrect size                                        ",&
 "Argument omit has incorect length                                       ",&
 "Argument piv has incorrect length                                       ",&
 "Argument prior_sscp has incorrect dimensions                            ",&
 "Argument r has incorect dimensions                                      ",&
+"Argument rate_beta has incorrect shape                                  ",&
+"Argument rate_sigma has incorrect shape                                 ",&
+"Argument sigma has incorrect shape                                      ",&
+"Argument sigma_series has incorrect shape                               ",&
+"Argument which_patt has incorrect size                                  ",&
 "Argument wkn has incorect length                                        ",&
 "Argument wkn1 or wkn2 has incorect length                               ",&
 "Argument wknp has incorect dimensions                                   ",&
 "Argument wkp has incorect length                                        ",&
 "Argument wkp1 or wkp2 has incorect length                               ",&
 "Argument wkpp has incorect dimensions                                   ",&
+"Argument worst_linear_coef has incorrect size                           ",&
+"Argument worst_series has incorrect size                                ",&
 "Argument x has more columns than rows                                   ",&
+"Argument ybar has incorrect size                                        ",&
+"Argument yimp has incorrect shape                                       ",&
+"Argument ysdv has incorrect size                                        ",&
 "Arguments a and b not conformable                                       ",&
 "Arguments a and c not conformable                                       ",&
 "Arguments b and c not conformable                                       ",&
@@ -37,7 +56,6 @@
 "EM algorithm aborted                                                    ",&
 "Eigen power method failed to converge                                   ",&
 "Error: stack size is too small                                          ",&
-"Failed to tabulate data                                                 ",&
 "Fewer than two observed cases available                                 ",&
 "Finite-differencing procedure strayed outside                           ",&
 "First element of v is not 1.D0                                          ",&
@@ -47,15 +65,12 @@
 "Incorrect dimensions for array argument beta                            ",&
 "Incorrect dimensions for array argument sigma                           ",&
 "Incorrect size for argument worst_linear_coef                           ",&
-"Input argument vec has length zero                                      ",&
-"Length of vec(1) greater than max_string_length                         ",&
 "Lower bound exceeds upper bound                                         ",&
 "MCMC procedure aborted                                                  ",&
 "Matrix apparently singular                                              ",&
 "Matrix not positive definite                                            ",&
 "Non-square matrix encountered; square expected                          ",&
 "Operation failed                                                        ",&
-"Output argument does not match table type                               ",&
 "Parameters out of order                                                 ",&
 "Pivot out of bounds                                                     ",&
 "Posterior distribution may not be proper                                ",&
@@ -64,7 +79,6 @@
 "Prior_df cannot be negative for ridge prior                             ",&
 "Random generator seeds have not been set                                ",&
 "Shape or scale parameter not positive                                   ",&
-"Table object is null                                                    ",&
 "Unable to allocate memory for object                                    ",&
 "Unable to deallocate memory for object                                  ",&
 "Unable to regress response on x                                         ",&
